@@ -42,9 +42,9 @@ def purge() -> None:
 
 
 @app.command(help="Look for new application releases")
-def update() -> None:
+def update(dry_run: bool = typer.Option(False, "--dry-run", "-d")) -> None:
     try:
-        sys.exit(updater.update(parse(settings.config).__root__))
+        sys.exit(updater.update(settings.config, dry_run))
     except Exception as e:
         error(e)
 
