@@ -2,16 +2,19 @@ import asyncio
 import hashlib
 import shutil
 from pathlib import Path
+from typing import Optional, Tuple
 
 import aiofiles
 import httpx
 import typer
 
-from .parser import RemoteFile
-
 _cache_path: Path = Path("/tmp/ops2deb_cache")
 
 
+def log(msg: str) -> None:
+    typer.secho(f"* {msg}", fg=typer.colors.WHITE)
+
+
 def purge_cache() -> None:
     shutil.rmtree(_cache_path, ignore_errors=True)
 
@@ -36,7 +39,7 @@ async def untar(file_path: Path) -> None:
         file_path.unlink()
 
 
-async def sha256(file_path: Path) -> str:
+async def compute_checksum(file_path: Path) -> str:
     sha256_hash = hashlib.sha256()
     with file_path.open("rb") as f:
         for byte_block in iter(lambda: f.read(4096), b""):
@@ -45,43 +48,44 @@ async def sha256(file_path: Path) -> str:
     return sha256_hash.hexdigest()
 
 
-async def download(url: str, file_path: Path) -> None:
-    tmp_path = f"{file_path}.part"
-    async with httpx.AsyncClient() as client:
-        async with client.stream("GET", url) as r:
-            # FIXME: https://github.com/Tinche/aiofiles/issues/91
-            async with aiofiles.open(tmp_path, "wb") as f:  # type: ignore
-                r.raise_for_status()
-                async for chunk in r.aiter_bytes():
-                    await f.write(chunk)
-    shutil.move(tmp_path, file_path)
-
-
-def log(msg: str) -> None:
-    typer.secho(f"* {msg}", fg=typer.colors.WHITE)
-
-
-async def fetch(remote_file: RemoteFile, output_path: Path) -> None:
+async def download(url: str, expected_hash: Optional[str] = None) -> Tuple[Path, str]:
     _cache_path.mkdir(exist_ok=True)
-    url_hash = hashlib.sha256(remote_file.url.encode()).hexdigest()
-    file_name = remote_file.url.split("/")[-1]
+    url_hash = hashlib.sha256(url.encode()).hexdigest()
+    file_name = url.split("/")[-1]
     file_path = _cache_path / f"{url_hash}_{file_name}"
+    tmp_path = f"{file_path}.part"
 
     if not file_path.is_file():
         log(f"Downloading {file_name}...")
-        await download(remote_file.url, file_path)
+        async with httpx.AsyncClient() as client:
+            async with client.stream("GET", url) as r:
+                # FIXME: https://github.com/Tinche/aiofiles/issues/91
+                async with aiofiles.open(tmp_path, "wb") as f:  # type: ignore
+                    r.raise_for_status()
+                    async for chunk in r.aiter_bytes():
+                        await f.write(chunk)
+        shutil.move(tmp_path, file_path)
 
-    log(f"Verifying {file_name}...")
-    digest = await sha256(file_path)
-    if digest != remote_file.sha256:
-        raise ValueError(
-            f"Wrong checksum for file {file_name}. "
-            f"Expected {remote_file.sha256}, got {digest}."
-        )
-    shutil.copy(file_path, output_path / file_name)
+    log(f"Computing checksum for {file_name}...")
+    computed_hash = await compute_checksum(file_path)
+
+    if expected_hash is not None:
+        if computed_hash != expected_hash:
+            raise ValueError(
+                f"Wrong checksum for file {file_name}. "
+                f"Expected {expected_hash}, got {computed_hash}."
+            )
+
+    return file_path, computed_hash
+
+
+async def fetch(url: str, expected_hash: str, save_path: Path) -> None:
+    file_name = url.split("/")[-1]
+    file_path, _ = await download(url, expected_hash)
+    shutil.copy(file_path, save_path / file_name)
 
     if file_name.endswith(".tar.gz"):
         log(f"Extracting {file_name}...")
-        await untar(output_path / file_name)
+        await untar(save_path / file_name)
 
     log(f"Done with {file_name}")
